pub enum Error {
IdentityTooLong,
DerivingRoot,
MalformedCiphertext,
}Expand description
Type for all errors that can occur when working with the HIBE implementations of this crate.
Variants
IdentityTooLong
Error returned when the identity that was supplied exceeded the given maximum hierarchy depth.
Can also be returned when trying to derive a key that would exceed the maximum identity depth.
DerivingRoot
Error returned when trying to derive the root identity, as there is no parent key for the root.
MalformedCiphertext
Error when the given ciphertext was malformed.
Note that this crate does not verify the integrity of ciphertexts. The absence of a malformation therefore does not mean that the ciphertext has not been tampered with!